==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V2beta1MetricSpecFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;

public interface V2beta1MetricSpecFluent<A extends V2beta1MetricSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ExternalMetricSource getExternal();
    public V2beta1ExternalMetricSource buildExternal();
    public A withExternal(V2beta1ExternalMetricSource external);
    public Boolean hasExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> withNewExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> withNewExternalLike(V2beta1ExternalMetricSource item);
    public V2beta1MetricSpecFluent.ExternalNested<A> editExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> editOrNewExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> editOrNewExternalLike(V2beta1ExternalMetricSource item);
    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ObjectMetricSource getObject();
    public V2beta1ObjectMetricSource buildObject();
    public A withObject(V2beta1ObjectMetricSource object);
    public Boolean hasObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> withNewObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> withNewObjectLike(V2beta1ObjectMetricSource item);
    public V2beta1MetricSpecFluent.ObjectNested<A> editObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> editOrNewObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> editOrNewObjectLike(V2beta1ObjectMetricSource item);
    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1PodsMetricSource getPods();
    public V2beta1PodsMetricSource buildPods();
    public A withPods(V2beta1PodsMetricSource pods);
    public Boolean hasPods();
    public V2beta1MetricSpecFluent.PodsNested<A> withNewPods();
    public V2beta1MetricSpecFluent.PodsNested<A> withNewPodsLike(V2beta1PodsMetricSource item);
    public V2beta1MetricSpecFluent.PodsNested<A> editPods();
    public V2beta1MetricSpecFluent.PodsNested<A> editOrNewPods();
    public V2beta1MetricSpecFluent.PodsNested<A> editOrNewPodsLike(V2beta1PodsMetricSource item);
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ResourceMetricSource getResource();
    public V2beta1ResourceMetricSource buildResource();
    public A withResource(V2beta1ResourceMetricSource resource);
    public Boolean hasResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> withNewResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> withNewResourceLike(V2beta1ResourceMetricSource item);
    public V2beta1MetricSpecFluent.ResourceNested<A> editResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> editOrNewResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> editOrNewResourceLike(V2beta1ResourceMetricSource item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();

    public interface ExternalNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ExternalMetricSourceFluent<V2beta1MetricSpecFluent.ExternalNested<N>>{

        
    public N and();    public N endExternal();
}
    public interface ObjectNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ObjectMetricSourceFluent<V2beta1MetricSpecFluent.ObjectNested<N>>{

        
    public N and();    public N endObject();
}
    public interface PodsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1PodsMetricSourceFluent<V2beta1MetricSpecFluent.PodsNested<N>>{

        
    public N and();    public N endPods();
}
    public interface ResourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ResourceMetricSourceFluent<V2beta1MetricSpecFluent.ResourceNested<N>>{

        
    public N and();    public N endResource();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V2beta1MetricSpecFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.kubernetes.client.fluent.Fluent;
import java.lang.StringBuffer;

public interface V2beta1MetricSpecFluent<A extends V2beta1MetricSpecFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildExternal instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ExternalMetricSource getExternal();
    public V2beta1ExternalMetricSource buildExternal();
    public A withExternal(V2beta1ExternalMetricSource external);
    public Boolean hasExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> withNewExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> withNewExternalLike(V2beta1ExternalMetricSource item);
    public V2beta1MetricSpecFluent.ExternalNested<A> editExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> editOrNewExternal();
    public V2beta1MetricSpecFluent.ExternalNested<A> editOrNewExternalLike(V2beta1ExternalMetricSource item);
    
/**
 * This method has been deprecated, please use method buildObject instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ObjectMetricSource getObject();
    public V2beta1ObjectMetricSource buildObject();
    public A withObject(V2beta1ObjectMetricSource object);
    public Boolean hasObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> withNewObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> withNewObjectLike(V2beta1ObjectMetricSource item);
    public V2beta1MetricSpecFluent.ObjectNested<A> editObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> editOrNewObject();
    public V2beta1MetricSpecFluent.ObjectNested<A> editOrNewObjectLike(V2beta1ObjectMetricSource item);
    
/**
 * This method has been deprecated, please use method buildPods instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1PodsMetricSource getPods();
    public V2beta1PodsMetricSource buildPods();
    public A withPods(V2beta1PodsMetricSource pods);
    public Boolean hasPods();
    public V2beta1MetricSpecFluent.PodsNested<A> withNewPods();
    public V2beta1MetricSpecFluent.PodsNested<A> withNewPodsLike(V2beta1PodsMetricSource item);
    public V2beta1MetricSpecFluent.PodsNested<A> editPods();
    public V2beta1MetricSpecFluent.PodsNested<A> editOrNewPods();
    public V2beta1MetricSpecFluent.PodsNested<A> editOrNewPodsLike(V2beta1PodsMetricSource item);
    
/**
 * This method has been deprecated, please use method buildResource instead.
 * @return The buildable object.
 */
@Deprecated public V2beta1ResourceMetricSource getResource();
    public V2beta1ResourceMetricSource buildResource();
    public A withResource(V2beta1ResourceMetricSource resource);
    public Boolean hasResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> withNewResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> withNewResourceLike(V2beta1ResourceMetricSource item);
    public V2beta1MetricSpecFluent.ResourceNested<A> editResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> editOrNewResource();
    public V2beta1MetricSpecFluent.ResourceNested<A> editOrNewResourceLike(V2beta1ResourceMetricSource item);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface ExternalNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ExternalMetricSourceFluent<V2beta1MetricSpecFluent.ExternalNested<N>>{

        
    public N and();    public N endExternal();
}
    public interface ObjectNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ObjectMetricSourceFluent<V2beta1MetricSpecFluent.ObjectNested<N>>{

        
    public N and();    public N endObject();
}
    public interface PodsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1PodsMetricSourceFluent<V2beta1MetricSpecFluent.PodsNested<N>>{

        
    public N and();    public N endPods();
}
    public interface ResourceNested<N> extends io.kubernetes.client.fluent.Nested<N>,V2beta1ResourceMetricSourceFluent<V2beta1MetricSpecFluent.ResourceNested<N>>{

        
    public N and();    public N endResource();
}


}
